@@ -2,6 +2,7 @@ from pathlib import Path
 import argparse
 import logging
 import os
+import sys
 # Local imports
 from . import audible_helper, helpers, m4b_helper
 
@@ -36,20 +37,33 @@ def run_all(inputs):
 def main():
     parser = argparse.ArgumentParser(
         description='m4bmerge cli'
-        )
+    )
     parser.add_argument(
         "-i", "--inputs",
         help="Input paths to process",
         nargs='+',
-        required=True,
+        required='--login' not in sys.argv,
         type=Path
-        )
+    )
     parser.add_argument(
         "--log_level",
         help="Set logging level"
-        )
+    )
+    parser.add_argument(
+        "--login",
+        default=False,
+        action="store_true",
+        help="Log in to Audible"
+    )
+
     args = parser.parse_args()
 
+    # Run login helper
+    if args.login:
+        aud = audible_helper.AudibleAuth()
+        run_auth = aud.handle_auth()
+        if not run_auth:
+            print("Logged in")
     # Get log level from system or input
     if args.log_level:
         numeric_level = getattr(logging, args.log_level.upper(), None)
@@ -59,15 +73,16 @@ def main():
     else:
         logging.basicConfig(level=os.environ.get("LOG_LEVEL", "INFO"))
     # Run through inputs
-    for inputs in args.inputs:
-        if inputs.exists():
-            run_all(inputs)
-        else:
-            logging.error(f"Input \"{inputs}\" does not exist")
+    if args.inputs:
+        for inputs in args.inputs:
+            if inputs.exists():
+                run_all(inputs)
+            else:
+                logging.error(f"Input \"{inputs}\" does not exist")
 
-    print('-' * 25)
-    print(f"Done processing {len(args.inputs)} inputs")
-    print('-' * 25)
+        print('-' * 25)
+        print(f"Done processing {len(args.inputs)} inputs")
+        print('-' * 25)
 
 
 # Only run call if using CLI directly
